Package: stcos
Type: Package
Title: Space-Time Change of Support
Version: 0.3.2
Authors@R: c(
	person(c("Andrew", "M."), "Raim", email = "andrew.raim@gmail.com", role = c("aut", "cre")),
	person(c("Scott", "H."), "Holan", role = c("aut", "res")),
	person(c("Jonathan", "R."), "Bradley", role = c("aut", "res")),
	person(c("Christopher", "K."), "Wikle", role = c("aut", "res")))
Author: Andrew M. Raim [aut, cre],
  Scott H. Holan [aut, res],
  Jonathan R. Bradley [aut, res],
  Christopher K. Wikle [aut, res]
Maintainer: Andrew M. Raim <andrew.raim@gmail.com>
URL: https://github.com/holans/ST-COS
Description: Spatio-temporal change of support (STCOS) methods are designed for
    statistical inference on geographic and time domains which differ from
    those on which the data were observed. In particular, a parsimonious class
    of STCOS models supporting Gaussian outcomes was introduced by Bradley,
    Wikle, and Holan <doi:10.1002/sta4.94>. The 'stcos' package contains tools
    which facilitate use of STCOS models.
License: MIT + file LICENSE
Depends: R (>= 3.5),
Imports: Rcpp, Matrix, sf, dplyr
LinkingTo: Rcpp, RcppArmadillo
Encoding: UTF-8
LazyData: true
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-05-11 18:11:48 UTC; araim
Repository: CRAN
Date/Publication: 2026-05-13 08:40:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-05-13 11:50:11 UTC; unix
Archs: stcos.so.dSYM
