# Generated by roxygen2: do not edit by hand

S3method(DIC,stcos_gibbs)
S3method(fitted,stcos_gibbs)
S3method(logLik,stcos_gibbs)
S3method(predict,stcos_gibbs)
S3method(print,stcos_gibbs)
export(DIC)
export(adjacency_matrix)
export(areal_spacetime_bisquare)
export(areal_spatial_bisquare)
export(autocov_VAR1)
export(car_precision)
export(cov_approx_blockdiag)
export(cov_approx_randwalk)
export(gibbs_stcos)
export(licols)
export(mle_stcos)
export(overlap_matrix)
export(prepare_stcos_demo)
export(rdomain)
export(spacetime_bisquare)
export(spatial_bisquare)
import(Matrix)
import(Rcpp)
import(sf)
importFrom(Rcpp,evalCpp)
importFrom(dplyr,"%>%")
importFrom(dplyr,mutate)
importFrom(dplyr,row_number)
importFrom(stats,dgamma)
importFrom(stats,dnorm)
importFrom(stats,logLik)
importFrom(stats,optim)
importFrom(stats,quantile)
importFrom(stats,rgamma)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
useDynLib(stcos, .registration = TRUE)
